@@ -1,6 +1,6 @@
 from django import forms
 from django.forms import ModelForm
-
+from tinymce.widgets import TinyMCE
 from suave.models import Page
 from collection.models import Product, Category
 
@@ -26,6 +26,9 @@ class PageForm(ModelForm):
     class Meta:
         model = Page
         exclude = ('identifier', 'url', 'template_override',)
+        widgets = {
+            'body': TinyMCE(attrs={'cols': 80, 'rows': 30})
+        }
 
 
 class CategoryForm(ModelForm):
