@@ -175,7 +175,7 @@ $(function() {
         });
     });
 
-    $('body').on('click', 'a.imageDeleteButton',
+    $('body').on('click', 'tr.productImageRow a.deleteButton',
         function(event) {
             event.preventDefault();
             row = $(this).closest('.productImageRow');
